<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu_HU" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Verzió %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 egy szabad szoftver, de a fejlesztése értékes időbe kerül.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Kérlek &lt;a href=&apos;%1&apos;&gt;adományozz&lt;/a&gt;, hogy folytatódhasson a %2 fejlesztése</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt; alatt lett kiadva</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Bezárás</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Amit mindig tudni akart %1-ról de sosem merte megkérdezni</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>Érdemes kipróbálni más alkalmazásaimat is:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, egy YouTube alkalmazás</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, egy Youtube zenelejátszó</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Fordítsa le a(z) %1 programot az anyanyelvére a(z) %2 segítségével.</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licencelve: %1</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Adja meg a licence részleteit</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;E-mail:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Kód:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Kérem licencelje %1  </translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Ez a demo már lejárt.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Licenc nélkül az alkalmazás lejár %1 nap múlva.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>A teljes verzió megvételével, támogatni fogja a kemény munkát amit belefektettem a(z) %1 fejlesztésébe.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Demo használata</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Licenc megadása:</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Licenc vásárlása</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>A teljes verzió engedi hogy a lejátszólistájához %1 számnál többet hozzáadjon, és a zenéit megszakítások nélkül hallgassa.</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Megvásárlás a %1-n</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Tudjon meg többet</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <source>Artist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Popularity</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sort by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Tudjon meg többet</translation>
    </message>
</context>
<context>
    <name>ArtistListView</name>
    <message>
        <source>Track Count</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Album Count</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Popularity</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sort by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Vissza</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Menj vissza</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Üdvözöl a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1-nak át kell vizsgálnia a zene gyűjteményed</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>iTunes gyűjtemény használata</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>%1 használata</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Könyvtár kiválasztása...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1-nak kapcsolódnia kell a Last.fm web szolgáltatásához, és át kell adnia az előadó neveket és album címeket, hogy letöltse a lemezborítókat, életrajzokat és sok mást.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Ha adatvédelmi aggályai lennének most kiléphet.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>Hol van a zene gyűjteménye?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Válassza ki a zene gyűjteménye helyét.</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Keresse meg a gyűjteményét</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>Egy vizsgálat már fut.</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>A %1 átvizsgálja a zene gyűjteményét.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>A %1 &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt;-t használja a zenéd katalógizálására</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>Ez időt vesz igénybe attól függően mekkora a gyűjteménye mérete és milyen gyors a hálózata sebessége.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Hozzon egy kávét</translation>
    </message>
</context>
<context>
    <name>DownloadWidget</name>
    <message>
        <source>Downloading update...</source>
        <translation>Frissítés letöltése...</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Dobja ide, a lejátszólistához hozzáadáshoz</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Előadók</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albumok</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Mappák</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Lejátszás</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szünet</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Lejátszás/Szünet</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Megállítás</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Lejátszás megállítása az aktuális szám után</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Következő szám</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Előző szám</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Hangerő növelése</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Hangerő csökkentése</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Némítás</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Előrelépés</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Visszalépés</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation>Hitelesítés sikertelen</translation>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation>Bejelentkezés ide: %1</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Felhasználónév</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Jelszó</translation>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation>Regisztráció a %1 oldalra</translation>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation>Elfelejtette a &lt;a href=&apos;%1&apos;&gt;felhasználónevét&lt;/a&gt; vagy a &lt;a href=&apos;%2&apos;&gt;jelszavát&lt;/a&gt;?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Vissza</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Ugrás az előző nézetre</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Információk megjelenítése az aktuális számról</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>&amp;Előző</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Ugrás az előző számra</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>K&amp;övetkező</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Következő szám átugrása</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Lejátszás</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Lejátszás elindítása</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Teljes képernyő</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Ugrás teljes képernyőre</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>El&amp;távolítás</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Kiválasztott számok eltávolítása a lejátszó listából</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>&amp;Fel</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>A kiválasztott számok feljebb helyezése a lejátszólistában</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>&amp;Le</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>A kiválasztott számok lejjebb helyezése a lejátszólistában</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Kilépés</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Viszlát</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>&amp;Gyűjtemény mappa változtatása</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Egy másik gyűjtemény mappa választása</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Weboldal</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 a weben</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>T&amp;ámogatás</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Kérem támogassa a %1 további fejlesztését</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Névjegy</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Információ %1-ról</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Tisztítás</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Minden szám törlése a lejátszó listáról</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>Véletlenszerű</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Véletlenszerű lejátszási mód</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Ismétlés</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Az első szám újra játszása, miután az összes szám le lett játszva</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Hangerő némítása</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Alkalmazás</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Playback</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>&amp;Lejátszólista</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>Né&amp;zet</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Segítség</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>%1 nyomása a hangerő növeléséhez, %2 a csökkentéséhez</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1 megnyitása</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Gyűjtemény frissítése...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Gyűjtemény frissítése - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Gyűjtemény frissítve</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Végzetes hiba: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Hiba: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Tel&amp;jes képernyő elhagyása</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Hátralévő idő:%1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Hangerő %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Hangerő némítva</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Hangerő visszahangosítva</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Teljes verzió beszerzése</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>A %1 %2 verziója most elérhető.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Emlékeztess késöbb</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Frissítés</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ablak</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimalizálás</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Bezárás</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>%1 megvásárlása...</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>&amp;Megállítás a szám után</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation>&amp;Továbbítás</translation>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation>Lejátszott számcímek küldése a %1 oldalnak</translation>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation>&amp;Kijelentkezés ebből: %1</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Hiba jelentése...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>%1 finished scanning your music collection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Ide dobja az elemeket</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Lejátszólista vége</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Ez csak egy demóverziója a %1-nak.</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Ez lehetőséget ad, hogy pár számot lejátsszon, kipróbálhatja az alkalmazást és megnézheti, hogy működik önnek.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Tovább</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Teljes verzió beszerzése</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>%1 új verziója elérhető!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 most elérhető. Önnek %3 van.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Szeretné letölteni most?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Verzió kihagyása</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Emlékeztessen később</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Frissítés telepítése</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Beillesztés</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>Ez a demo korlátozva van %1 számra a lejátszólistában.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>Lejátszólista üres</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 szám - Teljes hossz %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>A keresésnek nincs eredménye.</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Számok</translation>
    </message>
</context>
</TS>